/* global require */
define(['core', 'jquery', 'underscore', 'core_models/user', 'core_lib/alerts'],
  function (core, $, _, UserModel, Alerts) {

  $.ajaxPrefilter(function (options, original_options, request) {

    // prefix all application requests with the base URL
    if (options.url
        && (options.url.indexOf('config/') !== -1
            || options.url.indexOf('services/') !== -1
            || options.url.indexOf('user/') !== -1) // if the URL is going to a service...
        && options.url.indexOf(window.console_baseURL) !== 0) { // ... and the URL is not *already* prefixed with the base URL...

      // ... prepend the base URL to the service request
      options.url = window.console_baseURL + options.url;
    }

    request.fail(function(request) {

      // If a user gets logged out any subsequent calls to an endpoint behind console_auth will be denied with a 401.
      if (request.status === 401) {

        // close any previously open alerts, this one takes precedence
        $('div.alert-global').alert('close');

        var alert = new Alerts.error({
          classes: ['alert-global'],
          content: 'You are no longer logged in to the console. <a href="' + window.console_baseURL + '">Log back in.</a>'
        });

        $('#widget-container').before(alert.render().el);
      }

    });
  });

  var token = jQuery('meta[name="_csrf"]').attr('content');

  if (token) {
    $.ajaxSetup({
      beforeSend: function(xhr) {
        xhr.setRequestHeader('X_CSRF_TOKEN', token);
      }
    });
  }

  var applications = [],
      app_promise,
      user_promise,
      link_selector = '.node-requests-link',
      link_text = 'node requests';

  $('#header').load(
    '/header.html',
    function () {
      $('#header.dropdown').dropdown();

      $.ajax({
        url: 'services/certificates/api/v1/csr_count',
        success: function(response) {
          var count = response.request_count;
          $(link_selector).text(link_text + ' (' + count + ')');
        }
      });
    }
  );

  app_promise = $.getJSON('config/applications', function(data) {
    var apps = data.applications;
    if (apps) {

      for (var i = 0; i < apps.length; i++) {
        applications.push({
          channel: apps[i],
          element: '#' + apps[i] + 'app'
        })
      }
    }
  });

  // provide a default read only user
  core.user = new UserModel({});

  user_promise = $.getJSON('user/current', function(data) {

    if (data) {
      core.user = new UserModel(data);
    }

  });

  // When we've completed loading of the applications and our logged in user start each application
  $.when(app_promise, user_promise).done(function() {

    _(applications).each(function(application) {
      core.start(application);
    });

  });
});
