define(function() {

  "use strict";

  // This is present for IE8 compatibility and I don't know of any other files that get included in both
  // the main app *and* tests
  if (typeof Object.create !== 'function') {
    Object.create = function (o) {
      function F() {
      }

      F.prototype = o;
      return new F();
    };
  }

  require.config({

    // be forgiving of highly loaded servers and allow a long time for require to load files
    waitSeconds: 45,

    // error when loading non AMD files
    enforceDefine: true,

    // cache buster
    urlArgs: "bust=" +  (new Date()).getTime(),

    // Shim non AMD libraries such as Backbone, Lo-Dash and Handlebars
    shim: {
      'dom':        {
        exports: '$',
        deps:    ['jquery']
      },
      'backbone':   {
        deps:    ['underscore', 'dom'],
        exports: 'Backbone'
      },
      'deferred':   {
        exports: 'Deferred',
        deps:    ['dom']
      },
      'handlebars': {
        exports: 'Handlebars'
      },
      'stickit': {
        exports: 'Backbone.View', // this is just a placeholder due to stickit not exporting any actual symbols
        deps:    ['backbone']
      },
      'bootstrap': {
        exports: '$',
        deps: ['dom']
      }
    },

    paths: {
      jquery:           'vendor/jquery',
      dom:              'vendor/dom',
      underscore:       'vendor/lodash', // Lo-Dash is a drop-in replacement for Underscore
      text:             'vendor/text',
      backbone:         'vendor/backbone',
      handlebars:       'vendor/handlebars-1.0.0.beta.6',
      marionette:       'vendor/backbone.marionette',
      stickit:          'vendor/backbone.stickit',
      bootstrap:        'vendor/bootstrap',

      base:             'vendor/aura/facades/jquery',
      aura_core:        'vendor/aura/core',
      aura_perms:       'vendor/aura/permissions',
      aura_sandbox:     'vendor/aura/sandbox',

      backbone_core:    'vendor/aura/extensions/backbone/core',
      backbone_sandbox: 'vendor/aura/extensions/backbone/sandbox',

      // Console paths
      core:             'core',
      sandbox:          'sandbox',
      perms:            'permissions',
      widgets:          '../applications',
      core_lib:         'lib',
      core_models:      'models',
      core_views:       'views',
      core_collections: 'collections',
      core_templates:   'templates'
    }
  });
});